@@ -1,5 +1,7 @@
+"""Module for unittest."""
+
 import unittest
-from nose.tools import raises
+from nose.tools import raises # noqa
 from lru.lrucache import LRUCache
 
 class LRUCacheTest(unittest.TestCase):
@@ -7,12 +9,15 @@ class LRUCacheTest(unittest.TestCase):
         self.capacity = 10
         self.cache = LRUCache(self.capacity)
 
-        for i in range(self.capacity):
-            self.cache.set(1, int(i))
+        for index in range(self.capacity):
+            self.cache.set(1, int(index))
 
     def tearDown(self):
         self.cache = None
 
     @raises(KeyError)
+    def test_set(self):
+        self.cache.set(1, int(index))
+
     def test_get(self):
-        self.cache.set(1)
\ No newline at end of file
+        self.cache.get(1)
\ No newline at end of file
